==> vmmagent-0.6.4-sources.jar: org/ow2/jasmine/vmm/agent/driver/libvirt/LibvirtDriver.java <==
/**
 * JASMINe VMMapi: JASMINe Virtual Machine Management API
 * Copyright (C) 2009 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: XenDriver.java 3177 2009-03-20 13:30:34Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.vmm.agent.driver.libvirt;

import java.util.Map;

import javax.management.ObjectName;

import org.ow2.jasmine.vmm.agent.domain.ServerPool;
import org.ow2.jasmine.vmm.agent.driver.Driver;

/**
 * Libvirt driver
 */
public class LibvirtDriver implements Driver {
    public ServerPool newServerPool(final String name, final ObjectName objectName, final Map<String, String> attributes) {
        ServerPool pool = new LibvirtServerPool(name, objectName, attributes);
        return pool;
    }

}

==> vmmagent-0.6.5-sources.jar: org/ow2/jasmine/vmm/agent/driver/libvirt/LibvirtDriver.java <==
/**
 * JASMINe VMMapi: JASMINe Virtual Machine Management API
 * Copyright (C) 2010 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: LibvirtDriver.java 7455 2011-01-19 23:03:36Z dangtran $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.vmm.agent.driver.libvirt;

import java.util.Map;

import javax.management.ObjectName;

import org.ow2.jasmine.vmm.agent.domain.ServerPool;
import org.ow2.jasmine.vmm.agent.driver.Driver;

/**
 * Libvirt driver
 */
public class LibvirtDriver implements Driver {

    private static String[] attributes = {"sshRootPaswword", "sshPrivateKeyFile", "user", "password", "sharedImageStore",
        "sharedDiskStore", "hypervisor", "syncPeriodMillis"};

    public ServerPool newServerPool(final String name, final ObjectName objectName, final Map<String, String> attributes) {
        ServerPool pool = new LibvirtServerPool(name, objectName, attributes);
        return pool;
    }

    @Override
    public String[] getServerPoolCreationAttributes() {
        return LibvirtDriver.attributes;
    }

}
